@@ -6,11 +6,23 @@
 
 package org.mozilla.javascript;
 
-import org.mozilla.classfile.*;
-import java.lang.reflect.*;
-import java.io.*;
-import java.security.*;
-import java.util.*;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.lang.reflect.Modifier;
+import java.security.CodeSource;
+import java.security.ProtectionDomain;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.HashSet;
+import java.util.Map;
+
+import org.mozilla.classfile.ByteCode;
+import org.mozilla.classfile.ClassFileWriter;
 
 public final class JavaAdapter implements IdFunctionCall
 {
@@ -78,6 +90,7 @@ public final class JavaAdapter implements IdFunctionCall
         ctor.exportAsScopeProperty();
     }
 
+    @Override
     public Object execIdCall(IdFunctionObject f, Context cx, Scriptable scope,
                              Scriptable thisObj, Object[] args)
     {
@@ -120,7 +133,7 @@ public final class JavaAdapter implements IdFunctionCall
     {
         int N = args.length;
         if (N == 0) {
-            throw ScriptRuntime.typeError0("msg.adapter.zero.args");
+            throw ScriptRuntime.typeErrorById("msg.adapter.zero.args");
         }
 
         // Expected arguments:
@@ -140,7 +153,7 @@ public final class JavaAdapter implements IdFunctionCall
                 break;
             }
             if (!(arg instanceof NativeJavaClass)) {
-                throw ScriptRuntime.typeError2("msg.not.java.class.arg",
+                throw ScriptRuntime.typeErrorById("msg.not.java.class.arg",
                                                String.valueOf(classCount),
                                                ScriptRuntime.toString(arg));
             }
@@ -152,7 +165,7 @@ public final class JavaAdapter implements IdFunctionCall
             Class<?> c = ((NativeJavaClass) args[i]).getClassObject();
             if (!c.isInterface()) {
                 if (superClass != null) {
-                    throw ScriptRuntime.typeError2("msg.only.one.super",
+                    throw ScriptRuntime.typeErrorById("msg.only.one.super",
                               superClass.getName(), c.getName());
                 }
                 superClass = c;
@@ -190,7 +203,7 @@ public final class JavaAdapter implements IdFunctionCall
                 int index = ctors.findCachedFunction(cx, ctorArgs);
                 if (index < 0) {
                     String sig = NativeJavaMethod.scriptSignature(args);
-                    throw Context.reportRuntimeError2(
+                    throw Context.reportRuntimeErrorById(
                             "msg.no.java.ctor", adapterClass.getName(), sig);
                 }
 
@@ -384,7 +397,7 @@ public final class JavaAdapter implements IdFunctionCall
             for (int j = 0; j < methods.length; j++) {
                 Method method = methods[j];
                 int mods = method.getModifiers();
-                if (Modifier.isStatic(mods) || Modifier.isFinal(mods)) {
+                if (Modifier.isStatic(mods) || Modifier.isFinal(mods) || method.isDefault()) {
                     continue;
                 }
                 String methodName = method.getName();
@@ -487,7 +500,8 @@ public final class JavaAdapter implements IdFunctionCall
     private static void appendOverridableMethods(Class<?> c,
             ArrayList<Method> list, HashSet<String> skip)
     {
-        Method[] methods = c.getDeclaredMethods();
+        Method[] methods=c.isInterface() ? c.getMethods() : c.getDeclaredMethods();
+        
         for (int i = 0; i < methods.length; i++) {
             String methodKey = methods[i].getName() +
                 getMethodSignature(methods[i],
@@ -579,14 +593,8 @@ public final class JavaAdapter implements IdFunctionCall
         Context cx = Context.getCurrentContext();
         if (cx != null) {
             return doCall(cx, scope, thisObj, f, args, argsToWrap);
-        } else {
-            return factory.call(new ContextAction() {
-                public Object run(Context cx)
-                {
-                    return doCall(cx, scope, thisObj, f, args, argsToWrap);
-                }
-            });
         }
+        return factory.call(cx2 -> doCall(cx2, scope, thisObj, f, args, argsToWrap));
     }
 
     private static Object doCall(Context cx, Scriptable scope,
@@ -608,15 +616,11 @@ public final class JavaAdapter implements IdFunctionCall
 
     public static Scriptable runScript(final Script script)
     {
-        return (Scriptable)ContextFactory.getGlobal().call(
-            new ContextAction() {
-                public Object run(Context cx)
-                {
-                    ScriptableObject global = ScriptRuntime.getGlobal(cx);
-                    script.exec(cx, global);
-                    return global;
-                }
-            });
+        return ContextFactory.getGlobal().call(cx -> {
+            ScriptableObject global = ScriptRuntime.getGlobal(cx);
+            script.exec(cx, global);
+            return global;
+        });
     }
 
     private static void generateCtor(ClassFileWriter cfw, String adapterName,
@@ -915,8 +919,7 @@ public final class JavaAdapter implements IdFunctionCall
                 cfw.add(ByteCode.DRETURN);
                 break;
             default:
-                throw new RuntimeException("Unexpected return type " +
-                                           retType.toString());
+                throw new RuntimeException("Unexpected return type " + retType);
             }
 
         } else {
@@ -982,7 +985,7 @@ public final class JavaAdapter implements IdFunctionCall
         if (parms.length > 64) {
             // If it will be an issue, then passing a static boolean array
             // can be an option, but for now using simple bitmask
-            throw Context.reportRuntimeError0(
+            throw Context.reportRuntimeErrorById(
                 "JavaAdapter can not subclass methods with more then"
                 +" 64 arguments.");
         }
