@@ -4,42 +4,50 @@
 
 package org.mozilla.javascript.optimizer;
 
-import org.mozilla.javascript.*;
-import org.mozilla.javascript.ast.Jump;
-
+import java.io.PrintWriter;
+import java.io.StringWriter;
 import java.util.BitSet;
 import java.util.HashMap;
 import java.util.Map;
+import org.mozilla.javascript.Node;
+import org.mozilla.javascript.ObjArray;
+import org.mozilla.javascript.ObjToIntMap;
+import org.mozilla.javascript.Token;
+import org.mozilla.javascript.ast.Jump;
 
-import java.io.PrintWriter;
-import java.io.StringWriter;
+class Block {
 
-class Block
-{
+    private static class FatBlock {
 
-    private static class FatBlock
-    {
-
-        private static Block[] reduceToArray(ObjToIntMap map)
-        {
+        private static Block[] reduceToArray(ObjToIntMap map) {
             Block[] result = null;
             if (!map.isEmpty()) {
                 result = new Block[map.size()];
                 int i = 0;
                 ObjToIntMap.Iterator iter = map.newIterator();
                 for (iter.start(); !iter.done(); iter.next()) {
-                    FatBlock fb = (FatBlock)(iter.getKey());
+                    FatBlock fb = (FatBlock) (iter.getKey());
                     result[i++] = fb.realBlock;
                 }
             }
             return result;
         }
 
-        void addSuccessor(FatBlock b)  { successors.put(b, 0); }
-        void addPredecessor(FatBlock b)  { predecessors.put(b, 0); }
+        void addSuccessor(FatBlock b) {
+            successors.put(b, 0);
+        }
 
-        Block[] getSuccessors() { return reduceToArray(successors); }
-        Block[] getPredecessors() { return reduceToArray(predecessors); }
+        void addPredecessor(FatBlock b) {
+            predecessors.put(b, 0);
+        }
+
+        Block[] getSuccessors() {
+            return reduceToArray(successors);
+        }
+
+        Block[] getPredecessors() {
+            return reduceToArray(predecessors);
+        }
 
         // all the Blocks that come immediately after this
         private ObjToIntMap successors = new ObjToIntMap();
@@ -49,14 +57,12 @@ class Block
         Block realBlock;
     }
 
-    Block(int startNodeIndex, int endNodeIndex)
-    {
+    Block(int startNodeIndex, int endNodeIndex) {
         itsStartNodeIndex = startNodeIndex;
         itsEndNodeIndex = endNodeIndex;
     }
 
-    static void runFlowAnalyzes(OptFunctionNode fn, Node[] statementNodes)
-    {
+    static void runFlowAnalyzes(OptFunctionNode fn, Node[] statementNodes) {
         int paramCount = fn.fnode.getParamCount();
         int varCount = fn.fnode.getParamAndVarCount();
         int[] varTypes = new int[varCount];
@@ -74,7 +80,12 @@ class Block
 
         if (DEBUG) {
             ++debug_blockCount;
-            System.out.println("-------------------"+fn.fnode.getFunctionName()+"  "+debug_blockCount+"--------");
+            System.out.println(
+                    "-------------------"
+                            + fn.fnode.getFunctionName()
+                            + "  "
+                            + debug_blockCount
+                            + "--------");
             System.out.println(fn.fnode.toStringTree(fn.fnode));
             System.out.println(toString(theBlocks, statementNodes));
         }
@@ -89,7 +100,7 @@ class Block
             }
             System.out.println("Variable Table, size = " + varCount);
             for (int i = 0; i != varCount; i++) {
-                System.out.println("["+i+"] type: "+varTypes[i]);
+                System.out.println("[" + i + "] type: " + varTypes[i]);
             }
         }
 
@@ -98,13 +109,11 @@ class Block
                 fn.setIsNumberVar(i);
             }
         }
-
     }
 
-    private static Block[] buildBlocks(Node[] statementNodes)
-    {
+    private static Block[] buildBlocks(Node[] statementNodes) {
         // a mapping from each target node to the block it begins
-        Map<Node,FatBlock> theTargetBlocks = new HashMap<Node,FatBlock>();
+        Map<Node, FatBlock> theTargetBlocks = new HashMap<Node, FatBlock>();
         ObjArray theBlocks = new ObjArray();
 
         // there's a block that starts at index 0
@@ -112,32 +121,32 @@ class Block
 
         for (int i = 0; i < statementNodes.length; i++) {
             switch (statementNodes[i].getType()) {
-                case Token.TARGET :
-                {
-                    if (i != beginNodeIndex) {
-                        FatBlock fb = newFatBlock(beginNodeIndex, i - 1);
+                case Token.TARGET:
+                    {
+                        if (i != beginNodeIndex) {
+                            FatBlock fb = newFatBlock(beginNodeIndex, i - 1);
+                            if (statementNodes[beginNodeIndex].getType() == Token.TARGET) {
+                                theTargetBlocks.put(statementNodes[beginNodeIndex], fb);
+                            }
+                            theBlocks.add(fb);
+                            // start the next block at this node
+                            beginNodeIndex = i;
+                        }
+                    }
+                    break;
+                case Token.IFNE:
+                case Token.IFEQ:
+                case Token.GOTO:
+                    {
+                        FatBlock fb = newFatBlock(beginNodeIndex, i);
                         if (statementNodes[beginNodeIndex].getType() == Token.TARGET) {
                             theTargetBlocks.put(statementNodes[beginNodeIndex], fb);
                         }
                         theBlocks.add(fb);
-                        // start the next block at this node
-                        beginNodeIndex = i;
+                        // start the next block at the next node
+                        beginNodeIndex = i + 1;
                     }
-                }
-                break;
-                case Token.IFNE :
-                case Token.IFEQ :
-                case Token.GOTO :
-                {
-                    FatBlock fb = newFatBlock(beginNodeIndex, i);
-                    if (statementNodes[beginNodeIndex].getType() == Token.TARGET) {
-                        theTargetBlocks.put(statementNodes[beginNodeIndex], fb);
-                    }
-                    theBlocks.add(fb);
-                    // start the next block at the next node
-                    beginNodeIndex = i + 1;
-                }
-                break;
+                    break;
             }
         }
 
@@ -152,22 +161,21 @@ class Block
         // build successor and predecessor links
 
         for (int i = 0; i < theBlocks.size(); i++) {
-            FatBlock fb = (FatBlock)(theBlocks.get(i));
+            FatBlock fb = (FatBlock) (theBlocks.get(i));
 
             Node blockEndNode = statementNodes[fb.realBlock.itsEndNodeIndex];
             int blockEndNodeType = blockEndNode.getType();
 
             if ((blockEndNodeType != Token.GOTO) && (i < (theBlocks.size() - 1))) {
-                FatBlock fallThruTarget = (FatBlock)(theBlocks.get(i + 1));
+                FatBlock fallThruTarget = (FatBlock) (theBlocks.get(i + 1));
                 fb.addSuccessor(fallThruTarget);
                 fallThruTarget.addPredecessor(fb);
             }
 
-
-            if ( (blockEndNodeType == Token.IFNE)
+            if ((blockEndNodeType == Token.IFNE)
                     || (blockEndNodeType == Token.IFEQ)
-                    || (blockEndNodeType == Token.GOTO) ) {
-                Node target = ((Jump)blockEndNode).target;
+                    || (blockEndNodeType == Token.GOTO)) {
+                Node target = ((Jump) blockEndNode).target;
                 FatBlock branchTargetBlock = theTargetBlocks.get(target);
                 target.putProp(Node.TARGETBLOCK_PROP, branchTargetBlock.realBlock);
                 fb.addSuccessor(branchTargetBlock);
@@ -178,7 +186,7 @@ class Block
         Block[] result = new Block[theBlocks.size()];
 
         for (int i = 0; i < theBlocks.size(); i++) {
-            FatBlock fb = (FatBlock)(theBlocks.get(i));
+            FatBlock fb = (FatBlock) (theBlocks.get(i));
             Block b = fb.realBlock;
             b.itsSuccessors = fb.getSuccessors();
             b.itsPredecessors = fb.getPredecessors();
@@ -189,15 +197,13 @@ class Block
         return result;
     }
 
-    private static FatBlock newFatBlock(int startNodeIndex, int endNodeIndex)
-    {
+    private static FatBlock newFatBlock(int startNodeIndex, int endNodeIndex) {
         FatBlock fb = new FatBlock();
         fb.realBlock = new Block(startNodeIndex, endNodeIndex);
         return fb;
     }
 
-    private static String toString(Block[] blockList, Node[] statementNodes)
-    {
+    private static String toString(Block[] blockList, Node[] statementNodes) {
         if (!DEBUG) return null;
 
         StringWriter sw = new StringWriter();
@@ -207,12 +213,16 @@ class Block
         for (int i = 0; i < blockList.length; i++) {
             Block b = blockList[i];
             pw.println("#" + b.itsBlockID);
-            pw.println("from " + b.itsStartNodeIndex
-                    + " "
-                    + statementNodes[b.itsStartNodeIndex].toString());
-            pw.println("thru " + b.itsEndNodeIndex
-                    + " "
-                    + statementNodes[b.itsEndNodeIndex].toString());
+            pw.println(
+                    "from "
+                            + b.itsStartNodeIndex
+                            + " "
+                            + statementNodes[b.itsStartNodeIndex].toString());
+            pw.println(
+                    "thru "
+                            + b.itsEndNodeIndex
+                            + " "
+                            + statementNodes[b.itsEndNodeIndex].toString());
             pw.print("Predecessors ");
             if (b.itsPredecessors != null) {
                 for (int j = 0; j < b.itsPredecessors.length; j++) {
@@ -235,22 +245,21 @@ class Block
         return sw.toString();
     }
 
-    private static void reachingDefDataFlow(OptFunctionNode fn, Node[] statementNodes,
-                                            Block theBlocks[], int[] varTypes)
-    {
-/*
-    initialize the liveOnEntry and liveOnExit sets, then discover the variables
-    that are def'd by each function, and those that are used before being def'd
-    (hence liveOnEntry)
-*/
+    private static void reachingDefDataFlow(
+            OptFunctionNode fn, Node[] statementNodes, Block theBlocks[], int[] varTypes) {
+        /*
+            initialize the liveOnEntry and liveOnExit sets, then discover the variables
+            that are def'd by each function, and those that are used before being def'd
+            (hence liveOnEntry)
+        */
         for (int i = 0; i < theBlocks.length; i++) {
             theBlocks[i].initLiveOnEntrySets(fn, statementNodes);
         }
-/*
-    this visits every block starting at the last, re-adding the predecessors of
-    any block whose inputs change as a result of the dataflow.
-    REMIND, better would be to visit in CFG postorder
-*/
+        /*
+            this visits every block starting at the last, re-adding the predecessors of
+            any block whose inputs change as a result of the dataflow.
+            REMIND, better would be to visit in CFG postorder
+        */
         boolean visit[] = new boolean[theBlocks.length];
         boolean doneOnce[] = new boolean[theBlocks.length];
         int vIndex = theBlocks.length - 1;
@@ -282,18 +291,17 @@ class Block
                 vIndex--;
             }
         }
-/*
-        if any variable is live on entry to block 0, we have to mark it as
-        not jRegable - since it means that someone is trying to access the
-        'undefined'-ness of that variable.
-*/
+        /*
+                if any variable is live on entry to block 0, we have to mark it as
+                not jRegable - since it means that someone is trying to access the
+                'undefined'-ness of that variable.
+        */
 
         theBlocks[0].markAnyTypeVariables(varTypes);
     }
 
-    private static void typeFlow(OptFunctionNode fn, Node[] statementNodes,
-                                 Block theBlocks[], int[] varTypes)
-    {
+    private static void typeFlow(
+            OptFunctionNode fn, Node[] statementNodes, Block theBlocks[], int[] varTypes) {
         boolean visit[] = new boolean[theBlocks.length];
         boolean doneOnce[] = new boolean[theBlocks.length];
         int vIndex = 0;
@@ -303,8 +311,7 @@ class Block
             if (visit[vIndex] || !doneOnce[vIndex]) {
                 doneOnce[vIndex] = true;
                 visit[vIndex] = false;
-                if (theBlocks[vIndex].doTypeFlow(fn, statementNodes, varTypes))
-                {
+                if (theBlocks[vIndex].doTypeFlow(fn, statementNodes, varTypes)) {
                     Block succ[] = theBlocks[vIndex].itsSuccessors;
                     if (succ != null) {
                         for (int i = 0; i < succ.length; i++) {
@@ -328,20 +335,17 @@ class Block
         }
     }
 
-    private static boolean assignType(int[] varTypes, int index, int type)
-    {
+    private static boolean assignType(int[] varTypes, int index, int type) {
         int prev = varTypes[index];
         return prev != (varTypes[index] |= type);
     }
 
-    private void markAnyTypeVariables(int[] varTypes)
-    {
+    private void markAnyTypeVariables(int[] varTypes) {
         for (int i = 0; i != varTypes.length; i++) {
             if (itsLiveOnEntrySet.get(i)) {
                 assignType(varTypes, i, Optimizer.AnyType);
             }
         }
-
     }
 
     /*
@@ -352,49 +356,46 @@ class Block
         The itsNotDefSet is built reversed then flipped later.
 
     */
-    private void lookForVariableAccess(OptFunctionNode fn, Node n)
-    {
+    private void lookForVariableAccess(OptFunctionNode fn, Node n) {
         switch (n.getType()) {
             case Token.TYPEOFNAME:
-            {
-                // TYPEOFNAME may be used with undefined names, which is why
-                // this is handled separately from GETVAR above.
-                int varIndex = fn.fnode.getIndexForNameNode(n);
-                if (varIndex > -1 && !itsNotDefSet.get(varIndex))
-                    itsUseBeforeDefSet.set(varIndex);
-            }
-            break;
-            case Token.DEC :
-            case Token.INC :
-            {
-                Node child = n.getFirstChild();
-                if (child.getType() == Token.GETVAR) {
-                    int varIndex = fn.getVarIndex(child);
-                    if (!itsNotDefSet.get(varIndex))
+                {
+                    // TYPEOFNAME may be used with undefined names, which is why
+                    // this is handled separately from GETVAR above.
+                    int varIndex = fn.fnode.getIndexForNameNode(n);
+                    if (varIndex > -1 && !itsNotDefSet.get(varIndex))
                         itsUseBeforeDefSet.set(varIndex);
-                    itsNotDefSet.set(varIndex);
-                } else {
-                    lookForVariableAccess(fn, child);
                 }
-            }
-            break;
-            case Token.SETVAR :
-            case Token.SETCONSTVAR :
-            {
-                Node lhs = n.getFirstChild();
-                Node rhs = lhs.getNext();
-                lookForVariableAccess(fn, rhs);
-                itsNotDefSet.set(fn.getVarIndex(n));
-            }
-            break;
-            case Token.GETVAR :
-            {
-                int varIndex = fn.getVarIndex(n);
-                if (!itsNotDefSet.get(varIndex))
-                    itsUseBeforeDefSet.set(varIndex);
-            }
-            break;
-            default :
+                break;
+            case Token.DEC:
+            case Token.INC:
+                {
+                    Node child = n.getFirstChild();
+                    if (child.getType() == Token.GETVAR) {
+                        int varIndex = fn.getVarIndex(child);
+                        if (!itsNotDefSet.get(varIndex)) itsUseBeforeDefSet.set(varIndex);
+                        itsNotDefSet.set(varIndex);
+                    } else {
+                        lookForVariableAccess(fn, child);
+                    }
+                }
+                break;
+            case Token.SETVAR:
+            case Token.SETCONSTVAR:
+                {
+                    Node lhs = n.getFirstChild();
+                    Node rhs = lhs.getNext();
+                    lookForVariableAccess(fn, rhs);
+                    itsNotDefSet.set(fn.getVarIndex(n));
+                }
+                break;
+            case Token.GETVAR:
+                {
+                    int varIndex = fn.getVarIndex(n);
+                    if (!itsNotDefSet.get(varIndex)) itsUseBeforeDefSet.set(varIndex);
+                }
+                break;
+            default:
                 Node child = n.getFirstChild();
                 while (child != null) {
                     lookForVariableAccess(fn, child);
@@ -409,8 +410,7 @@ class Block
         Then walk the trees looking for defs/uses of variables
         and build the def and useBeforeDef sets.
     */
-    private void initLiveOnEntrySets(OptFunctionNode fn, Node[] statementNodes)
-    {
+    private void initLiveOnEntrySets(OptFunctionNode fn, Node[] statementNodes) {
         int listLength = fn.getVarCount();
         itsUseBeforeDefSet = new BitSet(listLength);
         itsNotDefSet = new BitSet(listLength);
@@ -420,7 +420,7 @@ class Block
             Node n = statementNodes[i];
             lookForVariableAccess(fn, n);
         }
-        itsNotDefSet.flip(0, listLength);         // truth in advertising
+        itsNotDefSet.flip(0, listLength); // truth in advertising
     }
 
     /*
@@ -429,20 +429,20 @@ class Block
         liveOnEntry = liveOnExit - defsInThisBlock + useBeforeDefsInThisBlock
 
     */
-    private boolean doReachedUseDataFlow()
-    {
+    private boolean doReachedUseDataFlow() {
         itsLiveOnExitSet.clear();
         if (itsSuccessors != null) {
             for (int i = 0; i < itsSuccessors.length; i++) {
                 itsLiveOnExitSet.or(itsSuccessors[i].itsLiveOnEntrySet);
             }
         }
-        return updateEntrySet(itsLiveOnEntrySet, itsLiveOnExitSet,
-                              itsUseBeforeDefSet, itsNotDefSet);
+        return updateEntrySet(
+                itsLiveOnEntrySet, itsLiveOnExitSet,
+                itsUseBeforeDefSet, itsNotDefSet);
     }
 
-    private boolean updateEntrySet(BitSet entrySet, BitSet exitSet,
-                                   BitSet useBeforeDef, BitSet notDef) {
+    private static boolean updateEntrySet(
+            BitSet entrySet, BitSet exitSet, BitSet useBeforeDef, BitSet notDef) {
         int card = entrySet.cardinality();
         entrySet.or(exitSet);
         entrySet.and(notDef);
@@ -456,9 +456,7 @@ class Block
             Literals,
             Arithmetic operations - always return a Number
     */
-    private static int findExpressionType(OptFunctionNode fn, Node n,
-                                          int[] varTypes)
-    {
+    private static int findExpressionType(OptFunctionNode fn, Node n, int[] varTypes) {
         switch (n.getType()) {
             case Token.NUMBER:
                 return Optimizer.NumberType;
@@ -482,6 +480,7 @@ class Block
             case Token.MUL:
             case Token.DIV:
             case Token.MOD:
+            case Token.EXP:
             case Token.BITOR:
             case Token.BITXOR:
             case Token.BITAND:
@@ -527,25 +526,29 @@ class Block
             case Token.ARRAYCOMP:
             case Token.ARRAYLIT:
             case Token.OBJECTLIT:
+            case Token.TEMPLATE_LITERAL:
+            case Token.BIGINT:
                 return Optimizer.AnyType; // XXX: actually, we know it's not
-            // number, but no type yet for that
+                // number, but no type yet for that
 
-            case Token.ADD: {
-                // if the lhs & rhs are known to be numbers, we can be sure that's
-                // the result, otherwise it could be a string.
-                Node child = n.getFirstChild();
-                int lType = findExpressionType(fn, child, varTypes);
-                int rType = findExpressionType(fn, child.getNext(), varTypes);
-                return lType | rType;    // we're not distinguishing strings yet
-            }
+            case Token.ADD:
+                {
+                    // if the lhs & rhs are known to be numbers, we can be sure that's
+                    // the result, otherwise it could be a string.
+                    Node child = n.getFirstChild();
+                    int lType = findExpressionType(fn, child, varTypes);
+                    int rType = findExpressionType(fn, child.getNext(), varTypes);
+                    return lType | rType; // we're not distinguishing strings yet
+                }
 
-            case Token.HOOK: {
-                Node ifTrue = n.getFirstChild().getNext();
-                Node ifFalse = ifTrue.getNext();
-                int ifTrueType = findExpressionType(fn, ifTrue, varTypes);
-                int ifFalseType = findExpressionType(fn, ifFalse, varTypes);
-                return ifTrueType | ifFalseType;
-            }
+            case Token.HOOK:
+                {
+                    Node ifTrue = n.getFirstChild().getNext();
+                    Node ifFalse = ifTrue.getNext();
+                    int ifTrueType = findExpressionType(fn, ifTrue, varTypes);
+                    int ifFalseType = findExpressionType(fn, ifFalse, varTypes);
+                    return ifTrueType | ifFalseType;
+                }
 
             case Token.COMMA:
             case Token.SETVAR:
@@ -556,28 +559,27 @@ class Block
                 return findExpressionType(fn, n.getLastChild(), varTypes);
 
             case Token.AND:
-            case Token.OR: {
-                Node child = n.getFirstChild();
-                int lType = findExpressionType(fn, child, varTypes);
-                int rType = findExpressionType(fn, child.getNext(), varTypes);
-                return lType | rType;
-            }
+            case Token.OR:
+                {
+                    Node child = n.getFirstChild();
+                    int lType = findExpressionType(fn, child, varTypes);
+                    int rType = findExpressionType(fn, child.getNext(), varTypes);
+                    return lType | rType;
+                }
         }
 
         return Optimizer.AnyType;
     }
 
-    private static boolean findDefPoints(OptFunctionNode fn, Node n,
-                                         int[] varTypes)
-    {
+    private static boolean findDefPoints(OptFunctionNode fn, Node n, int[] varTypes) {
         boolean result = false;
         Node first = n.getFirstChild();
         for (Node next = first; next != null; next = next.getNext()) {
             result |= findDefPoints(fn, next, varTypes);
         }
         switch (n.getType()) {
-            case Token.DEC :
-            case Token.INC :
+            case Token.DEC:
+            case Token.INC:
                 if (first.getType() == Token.GETVAR) {
                     // theVar is a Number now
                     int i = fn.getVarIndex(first);
@@ -586,24 +588,22 @@ class Block
                     }
                 }
                 break;
-            case Token.SETVAR :
-            case Token.SETCONSTVAR : {
-                Node rValue = first.getNext();
-                int theType = findExpressionType(fn, rValue, varTypes);
-                int i = fn.getVarIndex(n);
-                if (!(n.getType() == Token.SETVAR
-                        && fn.fnode.getParamAndVarConst()[i])) {
-                    result |= assignType(varTypes, i, theType);
+            case Token.SETVAR:
+            case Token.SETCONSTVAR:
+                {
+                    Node rValue = first.getNext();
+                    int theType = findExpressionType(fn, rValue, varTypes);
+                    int i = fn.getVarIndex(n);
+                    if (!(n.getType() == Token.SETVAR && fn.fnode.getParamAndVarConst()[i])) {
+                        result |= assignType(varTypes, i, theType);
+                    }
+                    break;
                 }
-                break;
-            }
         }
         return result;
     }
 
-    private boolean doTypeFlow(OptFunctionNode fn, Node[] statementNodes,
-                               int[] varTypes)
-    {
+    private boolean doTypeFlow(OptFunctionNode fn, Node[] statementNodes, int[] varTypes) {
         boolean changed = false;
 
         for (int i = itsStartNodeIndex; i <= itsEndNodeIndex; i++) {
@@ -616,19 +616,14 @@ class Block
         return changed;
     }
 
-    private void printLiveOnEntrySet(OptFunctionNode fn)
-    {
+    private void printLiveOnEntrySet(OptFunctionNode fn) {
         if (DEBUG) {
             for (int i = 0; i < fn.getVarCount(); i++) {
                 String name = fn.fnode.getParamOrVarName(i);
-                if (itsUseBeforeDefSet.get(i))
-                    System.out.println(name + " is used before def'd");
-                if (itsNotDefSet.get(i))
-                    System.out.println(name + " is not def'd");
-                if (itsLiveOnEntrySet.get(i))
-                    System.out.println(name + " is live on entry");
-                if (itsLiveOnExitSet.get(i))
-                    System.out.println(name + " is live on exit");
+                if (itsUseBeforeDefSet.get(i)) System.out.println(name + " is used before def'd");
+                if (itsNotDefSet.get(i)) System.out.println(name + " is not def'd");
+                if (itsLiveOnEntrySet.get(i)) System.out.println(name + " is live on entry");
+                if (itsLiveOnExitSet.get(i)) System.out.println(name + " is live on exit");
             }
         }
     }
@@ -638,10 +633,10 @@ class Block
     // all the Blocks that come immediately before this
     private Block[] itsPredecessors;
 
-    private int itsStartNodeIndex;       // the Node at the start of the block
-    private int itsEndNodeIndex;         // the Node at the end of the block
+    private int itsStartNodeIndex; // the Node at the start of the block
+    private int itsEndNodeIndex; // the Node at the end of the block
 
-    private int itsBlockID;               // a unique index for each block
+    private int itsBlockID; // a unique index for each block
 
     // reaching def bit sets -
     private BitSet itsLiveOnEntrySet;
@@ -651,6 +646,4 @@ class Block
 
     static final boolean DEBUG = false;
     private static int debug_blockCount;
-
 }
-
