@@ -6,28 +6,40 @@
 
 package org.mozilla.javascript.regexp;
 
-import org.mozilla.javascript.*;
+import org.mozilla.javascript.Context;
+import org.mozilla.javascript.Function;
+import org.mozilla.javascript.Kit;
+import org.mozilla.javascript.RegExpProxy;
+import org.mozilla.javascript.ScriptRuntime;
+import org.mozilla.javascript.Scriptable;
+import org.mozilla.javascript.ScriptableObject;
+import org.mozilla.javascript.Undefined;
 
 /**
  *
  */
 public class RegExpImpl implements RegExpProxy {
 
+    @Override
     public boolean isRegExp(Scriptable obj) {
         return obj instanceof NativeRegExp;
     }
 
+    @Override
     public Object compileRegExp(Context cx, String source, String flags)
     {
         return NativeRegExp.compileRE(cx, source, flags, false);
     }
 
+    @Override
     public Scriptable wrapRegExp(Context cx, Scriptable scope,
                                  Object compiled)
     {
-        return new NativeRegExp(scope, (RECompiled) compiled);
+        return NativeRegExpInstantiator
+                .withLanguageVersionScopeCompiled(cx.getLanguageVersion(), scope, (RECompiled) compiled);
     }
 
+    @Override
     public Object action(Context cx, Scriptable scope,
                          Scriptable thisObj, Object[] args,
                          int actionType)
@@ -39,23 +51,36 @@ public class RegExpImpl implements RegExpProxy {
         switch (actionType) {
           case RA_MATCH:
             {
-                NativeRegExp re = createRegExp(cx, scope, args, 1, false);
-                Object rval = matchOrReplace(cx, scope, thisObj, args,
-                                             this, data, re);
+                int optarg = Integer.MAX_VALUE;
+                if (cx.getLanguageVersion() < Context.VERSION_1_6) {
+                    optarg = 1;
+                }
+
+                NativeRegExp re = createRegExp(cx, scope, args, optarg, false);
+                Object rval = matchOrReplace(cx, scope, thisObj, args, this, data, re);
                 return data.arrayobj == null ? rval : data.arrayobj;
             }
 
           case RA_SEARCH:
             {
-                NativeRegExp re = createRegExp(cx, scope, args, 1, false);
-                return matchOrReplace(cx, scope, thisObj, args,
-                                      this, data, re);
+                int optarg = Integer.MAX_VALUE;
+                if (cx.getLanguageVersion() < Context.VERSION_1_6) {
+                    optarg = 1;
+                }
+
+                NativeRegExp re = createRegExp(cx, scope, args, optarg, false);
+                return matchOrReplace(cx, scope, thisObj, args, this, data, re);
             }
 
           case RA_REPLACE:
             {
-                boolean useRE = (args.length > 0 && args[0] instanceof NativeRegExp)
-                                || args.length > 2;
+                boolean useRE = args.length > 0 && args[0] instanceof NativeRegExp;
+
+                // ignore other parameters
+                if (cx.getLanguageVersion() < Context.VERSION_1_6) {
+                    useRE |= args.length > 2;
+                }
+
                 NativeRegExp re = null;
                 String search = null;
                 if (useRE) {
@@ -68,7 +93,9 @@ public class RegExpImpl implements RegExpProxy {
                 Object arg1 = args.length < 2 ? Undefined.instance : args[1];
                 String repstr = null;
                 Function lambda = null;
-                if (arg1 instanceof Function) {
+                if (arg1 instanceof Function
+                        && (cx.getLanguageVersion() < Context.VERSION_ES6
+                                || !(arg1 instanceof NativeRegExp))) {
                     lambda = (Function) arg1;
                 } else {
                     repstr = ScriptRuntime.toString(arg1);
@@ -89,6 +116,7 @@ public class RegExpImpl implements RegExpProxy {
                     int index = str.indexOf(search);
                     if (index >= 0) {
                         int slen = search.length();
+                        this.parens = null;
                         this.lastParen = null;
                         this.leftContext = new SubString(str, 0, index);
                         this.lastMatch = new SubString(str, index, slen);
@@ -127,7 +155,7 @@ public class RegExpImpl implements RegExpProxy {
         Scriptable topScope = ScriptableObject.getTopLevelScope(scope);
         if (args.length == 0 || args[0] == Undefined.instance) {
             RECompiled compiled = NativeRegExp.compileRE(cx, "", "", false);
-            re = new NativeRegExp(topScope, compiled);
+            re = NativeRegExpInstantiator.withLanguageVersionScopeCompiled(cx.getLanguageVersion(), topScope, compiled);
         } else if (args[0] instanceof NativeRegExp) {
             re = (NativeRegExp) args[0];
         } else {
@@ -140,7 +168,7 @@ public class RegExpImpl implements RegExpProxy {
                 opt = null;
             }
             RECompiled compiled = NativeRegExp.compileRE(cx, src, opt, forceFlat);
-            re = new NativeRegExp(topScope, compiled);
+            re = NativeRegExpInstantiator.withLanguageVersionScopeCompiled(cx.getLanguageVersion(), topScope, compiled);
         }
         return re;
     }
@@ -165,7 +193,7 @@ public class RegExpImpl implements RegExpProxy {
             else
                 result = Integer.valueOf(-1);
         } else if (data.global) {
-            re.lastIndex = 0d;
+            re.lastIndex = ScriptRuntime.zeroObj;
             for (int count = 0; indexp[0] <= str.length(); count++) {
                 result = re.executeRegExp(cx, scope, reImpl,
                                           str, indexp, NativeRegExp.TEST);
@@ -199,6 +227,7 @@ public class RegExpImpl implements RegExpProxy {
 
 
 
+    @Override
     public int find_split(Context cx, Scriptable scope, String target,
                           String separator, Scriptable reObj,
                           int[] ip, int[] matchlen,
@@ -217,7 +246,7 @@ public class RegExpImpl implements RegExpProxy {
             ip[0] = i;
             Object ret = re.executeRegExp(cx, scope, this, target, ip,
                                           NativeRegExp.TEST);
-            if (ret != Boolean.TRUE) {
+            if (!Boolean.TRUE.equals(ret)) {
                 // Mismatch: ensure our caller advances i past end of string.
                 ip[0] = ipsave;
                 matchlen[0] = 1;
@@ -282,7 +311,7 @@ public class RegExpImpl implements RegExpProxy {
                 return parsub;
             }
         }
-        return SubString.emptySubString;
+        return new SubString();
     }
 
     /*
@@ -512,6 +541,7 @@ public class RegExpImpl implements RegExpProxy {
      * a limit argument and accepts a regular expression as the split
      * argument.
      */
+    @Override
     public Object js_split(Context cx, Scriptable scope,
                                    String target, Object[] args)
     {
@@ -524,8 +554,12 @@ public class RegExpImpl implements RegExpProxy {
         if (limited) {
             /* Clamp limit between 0 and 1 + string length. */
             limit = ScriptRuntime.toUint32(args[1]);
-            if (limit > target.length())
+            if (limit == 0) {
+                return result;
+            }
+            if (limit > target.length()) {
                 limit = 1 + target.length();
+            }
         }
 
         // return an array consisting of the target if no separator given
@@ -726,8 +760,7 @@ public class RegExpImpl implements RegExpProxy {
 
     protected String          input;         /* input string to match (perl $_, GC root) */
     protected boolean         multiline;     /* whether input contains newlines (perl $*) */
-    protected SubString[]     parens;        /* Vector of SubString; last set of parens
-                                      matched (perl $1, $2) */
+    protected SubString[]     parens;        /* Vector of SubString; last set of parens matched (perl $1, $2) */
     protected SubString       lastMatch;     /* last string matched (perl $&) */
     protected SubString       lastParen;     /* last paren matched (perl $+) */
     protected SubString       leftContext;   /* input to left of last match (perl $`) */
