@@ -88,7 +88,7 @@ TestPrototype()
 
 
 function TestConstructor() {
- // Rhino assertEquals(0, Symbol.length);
+  assertEquals(0, Symbol.length);
   assertSame(Function.prototype, Symbol.__proto__)
   assertFalse(Object === Symbol.prototype.constructor)
   assertFalse(Symbol === Object.prototype.constructor)
