@@ -4,17 +4,16 @@
 
 package org.mozilla.javascript.tests;
 
+import static junit.framework.Assert.assertEquals;
+
+import java.io.IOException;
+
 import org.junit.Before;
 import org.junit.Test;
 import org.mozilla.javascript.CompilerEnvirons;
 import org.mozilla.javascript.Parser;
 import org.mozilla.javascript.ast.AstRoot;
 
-import java.io.IOException;
-import java.io.StringReader;
-
-import static junit.framework.Assert.assertEquals;
-
 public class BugGetterSetterTest {
     private CompilerEnvirons environment = new CompilerEnvirons();
 
@@ -38,7 +37,7 @@ public class BugGetterSetterTest {
                 "};\n";
 
         Parser parser = new Parser(environment);
-        AstRoot astRoot = parser.parse(new StringReader(script), null, 1);
+        AstRoot astRoot = parser.parse(script, null, 1);
         assertEquals(script, astRoot.toSource());
     }
 }
