@@ -6,10 +6,13 @@
  * Tests for the Object.getOwnPropertyNames(obj) method
  */
 package org.mozilla.javascript.tests.es5;
-import org.mozilla.javascript.*;
-import static org.mozilla.javascript.tests.Evaluator.eval;
 import static org.junit.Assert.assertEquals;
+import static org.mozilla.javascript.tests.Evaluator.eval;
+
 import org.junit.Test;
+import org.mozilla.javascript.NativeArray;
+import org.mozilla.javascript.NativeObject;
+import org.mozilla.javascript.ScriptableObject;
 
 public class ObjectGetOwnPropertyNamesTest {
 
