@@ -4,9 +4,9 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '9.2.1.7.js';
+gTestfile = '9.1.1.10.js';
 
-START("9.2.1.7 XMLList [[DeepCopy]]");
+START("9.1.1.10 - XML [[ResolveValue]]");
 
 var actual = 'Test not implemented';
 var expect = 'PASS';
@@ -14,4 +14,3 @@ var expect = 'PASS';
 TEST(1, expect, actual);
 
 END();
-
