@@ -3,10 +3,10 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '15.9.5.13-2.js';
+gTestfile = '15.9.5.13-6.js';
 
 /**
-   File Name:          15.9.5.13
+   File Name:          15.9.5.13.js
    ECMA Section:       15.9.5.13
    Description:        Date.prototype.getUTCDay
 
@@ -25,7 +25,7 @@ var TITLE   = "Date.prototype.getUTCDay()";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-addTestCase( TIME_0000 );
+addTestCase( UTC_FEB_29_2000 );
 
 test();
 
@@ -41,3 +41,4 @@ function addTestCase( t ) {
                   (new Date(d)).getUTCDay() );
   }
 }
+
