@@ -3,10 +3,10 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-322135-04.js';
+var gTestfile = 'regress-322135-02.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 322135;
-var summary = 'Array.prototype.unshift on Array with length 2^32-1';
+var summary = 'Array.prototype.concat on Array with length 2^32-1';
 var actual = 'Completed';
 var expect = 'Completed';
 
@@ -17,22 +17,16 @@ printStatus('This bug passes if it does not cause an out of memory error');
 printStatus('Other issues related to array length are not tested.');
  
 var length = 4294967295;
-var array = new Array(length);
+var array1 = new Array(length);
+var array2 = ['Kibo'];
+var array;
 
 try
 {
-  array.unshift('Kibo');
+  array = array1.concat(array2);
 }
 catch(ex)
 {
   printStatus(ex.name + ': ' + ex.message);
 }
 reportCompare(expect, actual, summary);
-
-//expect = 'Kibo';
-//actual = array[0];
-//reportCompare(expect, actual, summary + ': first prepended');
-
-//expect = length;
-//actual = array.length;
-//reportCompare(expect, actual, summary + ': array length unchanged');
