@@ -3,12 +3,12 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-309925-01.js';
+var gTestfile = 'regress-309925-02.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 309925;
-var summary = 'Correctly parse Date strings with HH:MM';
-var actual = new Date('Sep 24, 11:58 105') + '';
-var expect = new Date('Sep 24, 11:58:00 105') + '';
+var summary = 'Correctly parse Date strings with HH:MM(comment)';
+var actual = new Date('Sep 24, 11:58(comment) 105') + '';
+var expect = new Date('Sep 24, 11:58:00 (comment) 105') + '';
 
 printBugNumber(BUGNUMBER);
 printStatus (summary);
