@@ -3,18 +3,15 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-360969-05.js';
+var gTestfile = 'regress-452724-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 360969;
-var summary = '2^17: local function';
+var BUGNUMBER = 452724;
+var summary = 'Do not crash with JIT: @TraceRecorder::getThis';
 var actual = 'No Crash';
 var expect = 'No Crash';
 
-var global = this;
-
 //-----------------------------------------------------------------------------
 test();
-
 //-----------------------------------------------------------------------------
 
 function test()
@@ -22,23 +19,14 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  var start = new Date();
-  var p;
-  var i;
-  var limit = 2 << 16;
 
-  for (var i = 0; i < limit; i++)
-  {
-    eval('function pf' + i + '() {}');
-  }
+  jit(true);
+
+  for (var j=0;j<5;++j) { (0/0) in this; }
+
+  jit(false);
 
   reportCompare(expect, actual, summary);
 
-  var stop = new Date();
-
-  print('Elapsed time: ' + Math.floor((stop - start)/1000) + ' seconds');
-
   exitFunc ('test');
 }
-
