@@ -6,7 +6,7 @@
 var gTestfile = 'regress-352022.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 352022;
-var summary = 'decompilation of let, delete and parens';
+var summary = 'decompilation old, bad bug dropping parenthesis';
 var actual = '';
 var expect = '';
 
@@ -20,18 +20,12 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  var f;
 
-  f = function() { g(h) = (delete let (y) 3); }
+  var f = function (){a[b] = (c, d)}
   actual = f + '';
-  expect = 'function () {\n    g(h) = ((let (y) 3), true);\n}';
-  compareSource(expect, actual, summary + ': 1');
+  expect = 'function () {\n    a[b] = (c, d);\n}';
 
-  f = function () {    g(h) = ((let (y) 3), true);}
-  actual = f + '';
-  expect = 'function () {\n    g(h) = ((let (y) 3), true);\n}';
-  compareSource(expect, actual, summary + ': 2');
+  compareSource(expect, actual, summary);
 
   exitFunc ('test');
 }
