@@ -3,10 +3,10 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-349012-02.js';
+var gTestfile = 'regress-349012-01.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 349012;
-var summary = 'generators with nested try finally blocks';
+var summary = 'closing a generator fails to report error if yield during close is ignored';
 var actual = '';
 var expect = '';
 
@@ -15,17 +15,18 @@ var expect = '';
 test();
 //-----------------------------------------------------------------------------
 
+if (typeof quit != 'undefined')
+{
+  quit(0);
+}
+
 function test()
 {
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
 
-  expect = "[object StopIteration]";
-  var expectyield   = "12";
-  var expectfinally = "Inner finally,Outer finally";
-  var actualyield = "";
-  var actualfinally = "";
+  expect = "Inner finally,Outer finally";
 
   function gen()
   {
@@ -33,30 +34,19 @@ function test()
       try {
         yield 1;
       } finally {
-        actualfinally += "Inner finally";
+        actual += "Inner finally";
         yield 2;
       }
     } finally {
-      actualfinally += ",Outer finally";
+      actual += ",Outer finally";
     }
   }
 
   var iter = gen();
-  actualyield += iter.next();
-  actualyield += iter.next();
-  try
-  {
-    actualyield += iter.next();
-    actual = "No exception";
-  }
-  catch(ex)
-  {
-    actual = ex + '';
-  }
- 
-  reportCompare(expect, actual, summary);
-  reportCompare(expectyield, actualyield, summary);
-  reportCompare(expectfinally, actualfinally, summary);
+  iter.next();
+  iter = null;
+  gc();
 
+  reportCompare(expect, actual, summary);
   exitFunc ('test');
 }
