@@ -3,31 +3,30 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-465460-05.js';
+var gTestfile = 'regress-465567-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 465460;
-var summary = 'TM: valueOf in a loop: do not assert';
+var BUGNUMBER = 465567;
+var summary = 'TM: Weirdness with var, let, multiple assignments';
 var actual = '';
 var expect = '';
 
+printBugNumber(BUGNUMBER);
+printStatus (summary);
 
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
+expect = '99999';
 
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
+jit(true);
 
-  jit(true);
-
-  for (var j = 0; j < 3; ++j) { 1 & Date; }
-
-  jit(false);
-
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
+for (let j = 0; j < 5; ++j) {
+  e = 9;
+  print(actual += '' + e);
+  e = 47;
+  if (e & 0) {
+    var e;
+    let e;
+  }
 }
+
+jit(false);
+
+reportCompare(expect, actual, summary);
