@@ -22,7 +22,7 @@ function test()
   printStatus (summary);
 
   var f = function () { for (("p" in a); 0;) { } }
-  expect = 'function () {\n    for (("p" in a); 0;) {\n    }\n}';
+  expect = 'function () {\n    for (("p" in a); false;) {\n    }\n}';
   actual = f + '';
 
   compareSource(expect, actual, summary);
