@@ -21,7 +21,7 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
-  expect = /TypeError: \(let \(a = undefined\) a\) (is undefined|has no properties)/;
+  expect = /TypeError: let \(a = undefined\) a (is undefined|has no properties)/;
   try
   {
     (let (a=undefined) a).b = 3;
