@@ -6,8 +6,16 @@
 
 package org.mozilla.javascript.xmlimpl;
 
-import org.mozilla.javascript.*;
-import org.mozilla.javascript.xml.*;
+import org.mozilla.javascript.Context;
+import org.mozilla.javascript.IdFunctionObject;
+import org.mozilla.javascript.Kit;
+import org.mozilla.javascript.NativeWith;
+import org.mozilla.javascript.Node;
+import org.mozilla.javascript.Ref;
+import org.mozilla.javascript.ScriptRuntime;
+import org.mozilla.javascript.Scriptable;
+import org.mozilla.javascript.Undefined;
+import org.mozilla.javascript.xml.XMLObject;
 
 /**
  *  This abstract class describes what all XML objects (XML, XMLList) should
@@ -16,6 +24,7 @@ import org.mozilla.javascript.xml.*;
  * @see XML
  */
 abstract class XMLObjectImpl extends XMLObject {
+    private static final long serialVersionUID = -2553684605738101761L;
     private static final Object XMLOBJECT_TAG = "XMLObject";
     private XMLLibImpl lib;
     private boolean prototypeFlag;
@@ -611,9 +620,7 @@ abstract class XMLObjectImpl extends XMLObject {
         }
 
         // All (XML|XMLList).prototype methods require thisObj to be XML
-        if (!(thisObj instanceof XMLObjectImpl))
-            throw incompatibleCallError(f);
-        XMLObjectImpl realThis = (XMLObjectImpl)thisObj;
+        XMLObjectImpl realThis = ensureType(thisObj, XMLObjectImpl.class, f);
 
         XML xml = realThis.getXML();
         switch (id) {
